California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 070 - REQUIRES LEGISLATIVE SUPERMAJORITY VOTE APPROVING USE OF CAP-AND-TRADE RESERVE FUND. LEGISLATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1403055 | MAYES BALLOT MEASURE COMMITTEE TO SUPPORT ACA 1/PROPOSITION 70; ASSEMBLYMAN CHAD | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1404758 | PROTECT CLIMATE FUNDS AND STOP PROP 70, CEJA ACTION COMMITTEE, A PROJECT OF TIDES ADVOCACY | OPPOSE